// Load dataset from Gist link
const csvUrl =
  'https://gist.githubusercontent.com/sriharsha729/12a0f4b12c79ecc6cebdfd46d546022b/raw/7a2c46b2a657b59f72efa384ae6dd9a9e34645b1/Cosmetics.csv';

const main = async () => {
  // Load dataset from Gist link
  const data = await d3.csv(csvUrl);

  // Calculate counts of each skin type
  const counts = {};
  data.forEach((d) => {
    if (d.Sensitive in counts) {
      counts[d.Sensitive]++;
    } else {
      counts[d.Sensitive] = 1;
    }
  });

  // Convert counts to an array of objects
  const pieData = Object.keys(counts).map((key) => ({
    skinType: key,
    count: counts[key],
  }));

  // SVG setup
  const width = 400;
  const height = 400;
  const radius = Math.min(width, height) / 2;

  const svg = d3
    .select('body')
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr(
      'transform',
      `translate(${width / 2}, ${height / 2})`,
    );

  // Pie chart creation
  const color = d3
    .scaleOrdinal()
    .domain(pieData.map((d) => d.skinType))
    .range(d3.schemeCategory10);

  const pie = d3.pie().value((d) => d.count);

  const data_ready = pie(pieData);

  // Draw pie slices
  svg
    .selectAll('path')
    .data(data_ready)
    .enter()
    .append('path')
    .attr('d', d3.arc().innerRadius(0).outerRadius(radius))
    .attr('fill', (d) => color(d.data.skinType))
    .attr('stroke', 'black')
    .style('stroke-width', '2px');

  // Adding legend
  const legend = svg
    .selectAll('.legend')
    .data(data_ready)
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr(
      'transform',
      (d, i) => `translate(-80,${i * 20})`,
    );

  legend
    .append('rect')
    .attr('x', width - 18)
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', (d) => color(d.data.skinType));

  legend
    .append('text')
    .attr('x', width - 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .text((d) => d.data.skinType);

  // Adding labels for X and Y axis
  svg
    .append('text')
    .attr(
      'transform',
      `translate(${width / 2}, ${height + 30})`,
    )
    .style('text-anchor', 'middle')
    .text('Skin Types');

  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Count');
};

main();
